import {
  select,
  json,
  hierarchy,
  linkHorizontal,
  zoom,
  event
} from 'd3';

var svg = select("svg"),
    width = +svg.attr("width"),
    height = +svg.attr("height"),
    g = svg.append("g").attr("transform", "translate(" + (width / 24+300) + "," + (height / 4) + ")");

var stratify = d3.stratify()
    .parentId(function(d) { return d.id.substring(0, d.id.lastIndexOf("|")); });

var tree = d3.tree()
    .size([2 * Math.PI, 240])
    .separation(function(a, b) { return (a.parent == b.parent ? 1 : 2) / a.depth; });

d3.json("data.json", function(error, data) {
  if (error) throw error;

  var root = tree(hierarchy(data));

  var link = g.selectAll(".link")
    .data(root.links())
    .enter().append("path")
      .attr("class", "link")
      .attr("d", d3.linkRadial()
          .angle(function(d) { return d.x; })
          .radius(function(d) { return d.y; }));

  var node = g.selectAll(".node")
    .data(root.descendants())
    .enter().append("g").attr("class", function(d) { return "node" + (d.children ? " node--internal" : " node--leaf"); })
      .attr("transform", function(d) { return "translate(" + radialPoint(d.x, d.y) + ")"; });

  node.append("circle")
      .attr("r", 2.5);

  node.filter(function(d) { return d.depth < 3 })
    	.append("text")
      .attr("dy", "0.31em")
      .attr("x", function(d) { return d.x < Math.PI === !d.children ? 2 : -6; })
      .attr("text-anchor", function(d) { return d.x < Math.PI === !d.children ? "start" : "end"; })
      .attr("transform", function(d) { 
  			if(d.depth == 1 || d.depth == 2 || d.depth == 3) {
    			return "rotate(" + (d.x < Math.PI ? d.x - Math.PI / 2 : d.x + Math.PI / 2) * 180 / Math.PI + ")";
  			}else{
  				return "rotate(0)";
  			}
  		})
  		.attr('font-size', d => getFontSize(d.depth))//console.log(d.depth))//getFontSize(d.depth))
  		.text(function(d) { return (d.data.data.id); });
      // .text(function(d) { return d.id.substring(d.id.lastIndexOf("|") + 1); });
  
  
});

function getDisTxt(x, txt) {
	var random = d3.randomUniform(1, 10);
  if(x==2)
  {
    if(random<2)
    {
    	return txt;
    }
    else
    {
    	return '';
    }
  }else{
  	return txt;
  }
  return txt;
}

function getFontSize(x) {
	if(x == 0) {
    return '0.7em';
  }else if(x == 1) {
  	return '0.7em';
  } else if(x == 2) {
  	return '0.5em';
  } else if(x == 3) {
  	return '0.01em';
  }
}

function radialPoint(x, y) {
  return [(y = +y) * Math.cos(x -= Math.PI /2), y * Math.sin(x)];
}